#
# spec file for package pithos
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012-2014 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global appid io.github.Pithos
Name:           pithos
Version:        1.2.1
Release:        bp153.1.13
Summary:        Native Pandora Radio client for Linux
License:        GPL-3.0
Group:          Productivity/Multimedia/Other
Url:            https://pithos.github.io/
Source0:        https://github.com/pithos/pithos/releases/download/%{version}/pithos-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gdk-pixbuf-devel
BuildRequires:  glib2-devel
# Needed for automatic typelib() Requires.
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python3-devel >= 3.4
BuildRequires:  update-desktop-files
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-good
Requires:       python3-cairo
Requires:       python3-gobject-Gdk
# Implementation of secret service
Recommends:     gnome-keyring
BuildArch:      noarch

%description
Pithos is a native Pandora Radio client for Linux. It's much more
lightweight than the Pandora.com web client, and integrates with desktop
features such as media keys, notifications, and the sound menu.

%prep
%autosetup

%build
%configure
make %{?_smp_mflags}

%install
%make_install

# Remove unnecessary icons
rm -rf %{buildroot}%{_datadir}/icons/ubuntu-mono*

%suse_update_desktop_file %{appid}
%fdupes -s %{buildroot}%{python3_sitelib}

%post
%glib2_gsettings_schema_post
%desktop_database_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc license README.md
%{_bindir}/%{name}
%{python3_sitelib}/%{name}/
%{_datadir}/%{name}/
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{appid}.appdata.xml

%changelog
* Thu Aug  4 2016 dimstar@opensuse.org
- Replace python3-gobject Requires with python3-gobject-Gdk since
  this was split for X-less setups, but pitos uses Gdk features.
* Wed Aug  3 2016 tingping@fedoraproject.org
- Update to 1.2.1:
  + Show a useful error dialog if no secret service found
  + Improvements to handling login credential changes
  + Fix icon name for main window
  + notification_icon: Fix visible toggle with AppIndicator going out of sync
  + mpris: Fix GetCurrentSong() in legacy interface
- Changes from 1.2.0:
  + Migrate build system to Autotools
  + Migrate settings to GSettings
  + Store password with SecretService (libsecret)
  + Remove all dependencies on dbus-python
  + Add extensive keyboard shortcuts for the main window
    + Add Keyboard Shortcuts help window on Gtk 3.20+
  + Add initial support for translations (translators needed!)
  + Add explicit content filter option
  + Fix high CPU usage with Ubuntu's default theme
  + Redesign all dialogs to use Headerbars
  + Redesign stations dropdown as a Popover with searching and sorting
  + Improve integration with Flatpak
    + Use Gio to open URIs
    + Rename icons and data files to match app id
  + mpris:
    + Effectively rewritten to better follow the spec
    + Reference album art as locally downloaded files
  + notify: Fix Ubuntu sometimes showing wrong art
  + lastfm: Fix now playing not being set
- Changes from 1.1.2:
  + Fix SSL error with Pandora One
  + Fix pacparser usage
  + Fix PyGObject 3.18+ warnings
  + notify: Fix album art not showing up
  + notification_icon:
    + Always use AppIndicator if installed (Fixes KDE 5, Elementary)
    + Add scroll to change volume with AppIndicator
    + Toggle visibility on middle  +click with AppIndicator
  + mediakeys: Add support for DBUS bindings on MATE
  + lastfm: Don't scrobble ads
- Changes from 1.1.1:
  + Fix erratic buffering behavior
  + Clarified license in Readme
  + Add explicit version check for Gtk 3.14
- Changes from 1.1.0:
  + Redesign plugin preferences (Now requires Gtk 3.14)
  + Fix locking up when buffering a song (#94)
  + Make lastfm an optional plugin
  + Make MPRIS an optional plugin
  + Update various icons
  + Minor performance improvements
  + MPRIS: Add property introspection
  + MPRIS: Add song rating `pithos:rating`
  + Notify: Fix escaping text when not needed
- Update Url
- Specify required Python version
- Change depedencies for current release
- Change build system for autotools
- Change data file references to new app id
* Tue Apr  5 2016 dimstar@opensuse.org
- Call fdupes only over pyton3_sitelib: ensure that
  /usr/share/icons contains actual files and not symlinks.
* Sun Nov 30 2014 malcolmlewis@opensuse.org
- Update to version 1.0.1:
  + Automatically install missing codecs if supported.
  + Save window position between sessions.
  + Fix saving last station on quit.
  + Fix pacparser support.
  + Improve pandora module docs.
  + Add setup.py command to build docs.
  + Add appdata file.
  + Notification_icon: Make toggling visibility more reliable.
  + mpris: Fix exception when querying positon.
  + mpris: Implement setting volume.
- Update fixes Pandora stream and hangs at "loading songs" This
  occurs randomly, sometimes very frequently (boo#907701).
* Tue Aug  5 2014 malcolmlewis@opensuse.org
- Update to version 1.0.0:
  + Move to Python 3, Gtk3 and GStreamer 1.0.
  + Fix issue causing large amounts of buffering.
  + Add indication when songs are replaced by ads.
  + Add bitrate to song description.
  + Add new icon.
  + Add playback controls to notifications.
  + Add support for Proxy Auto-Config
- Changes from version 0.3.18:
  + Fix high quality setting.
  + Fix screensaver_pause plugin on DE's other than Gnome.
  + Fix fake client.
  + Pause playback when space is pressed.
  + Implement the rest of MPRIS 2.2.
  + No longer bundle pylast.
  + Have gstreamer respect proxy.
  + Move to setuptools.
- Update Url.
- Update python-devel, python-desturils-extra and python-setuptools
  with their respective python3-* BuildRequires: follow the port to
  python3.
- Replace gstreamer-0_10-* BuildRequires with the GStreamer 1.0
  related gstreamer-* counterparts.
- Drop obsolete openSUSE version checks from spec.
- Add gobject-introspection BuildRequires for automatic typelib()-
  Requires.
- Drop python-gtk and python-notify Requires: no longer required.
* Tue May 22 2012 dimstar@opensuse.org
- Change license to be GPL-3.0, as per legal review (bnc#763416).
* Fri May  4 2012 malcolmlewis@opensuse.org
- Update to version 0.3.17:
  + Switch to JSON API to work around XMLRPC API update
    (lp#988395).
  + Fix rename station menu item.
  + Update FSF address in pylast.py (lp#987883).
  + Remove #! header from files that are not executable
    (lp#988364).
- Drop pithos-fix-incorrect-fsf-address.patch: fixed upstream.
- Drop pithos-fix-non-executable-script.patch: fixed upstream.
* Wed Apr 25 2012 malcolmlewis@opensuse.org
- Updated to new version 0.3.16:
  + Numerous bugfixes.
  + Minor User Interface improvements.
- Add pithos-fix-incorrect-fsf-address.patch: Fix incorrect FSF
  address (lp#987883).
- Add pithos-fix-non-executable-script.patch: Fix file contains a
  shebang (lp#988364).
* Sat Apr 14 2012 malcolmlewis@opensuse.org
- New bzr version now at revision 202:
  + Tweaks to prefs dialog.
  + Pass album art URL to MPRIS for Unity sound menu (lp#876984).
  + Add "Quit" item to menu (lp#904589).
  + Better handling of fatal gstreamer codec errors.
  + Add "Player" to category to allow build on openSUSE Open Build
    service (lp#976327).
  + Handle urllib HTTPError.
- Drop pithos-fix-no-sufficient-category-definition.patch as this
  has been upstreamed.
* Sun Apr  8 2012 malcolmlewis@opensuse.org
- Initial build.
- Add pithos-fix-no-sufficient-category-definition.patch: Add
  Player to categories in desktop file (lp#976327).
